mynewf: Another function

Description Usage Arguments Details Value Examples

View source: R/myttest.R

Description

Another function

Usage

1
mynewf(x)

Arguments

x

vector

Details

You may add as many functions as you wish in this file and document them in Roxygen

Value

plot

Examples

1
x<-1:10;mynewf(x)

MATHSTATSOU/shinyexample documentation built on May 19, 2020, 1:10 a.m.