plot.mytt: Method for plotting class mytt

Description Usage Arguments Details Value Examples

View source: R/plotmytt.R

Description

Makes a boxplot using an object of class mytt

Usage

1
2
## S3 method for class 'mytt'
plot(x, ...)

Arguments

x

object class mytt

...

extra options to be sent to method

Details

The function myttest() produces a list of class mytt, which has three components. These are sourced from the object and used in plot.mytt()

Value

A boxplot of the two samples using ggplot()

Examples

1
l<-myttest(x=rnorm(30), y=rnorm(40,0.5));plot(l)

MATHSTATSOU/shinyexample documentation built on May 19, 2020, 1:10 a.m.